﻿/*
Copyright (c) 2003-2023, CKSource Holding sp. z o.o. All rights reserved.
CKEditor 4 LTS ("Long Term Support") is available under the terms of the Extended Support Model.
*/
CKEDITOR.plugins.setLang( 'colorbutton', 'el', {
	auto: 'Αυτόματα',
	bgColorTitle: 'Χρώμα Φόντου',
	colors: {
		'000': 'Μαύρο',
		'800000': 'Καστανέρυθρο',
		'8B4513': 'Saddle Brown',
		'2F4F4F': 'Dark Slate Gray',
		'008080': 'Βαθυκύανο',
		'000080': 'Μπλε μαρέν',
		'4B0082': 'Ινδικό',
		'696969': 'Σκούρο Γκρι',
		B22222: 'Ανοικτό Κόκκινο',
		A52A2A: 'Καφέ',
		DAA520: 'Golden Rod',
		'006400': 'Σκούρο Πράσινο',
		'40E0D0': 'Τυρκουάζ',
		'0000CD': 'Medium Blue',
		'800080': 'Μοβ',
		'808080': 'Γκρι',
		F00: 'Κόκκινο',
		FF8C00: 'Σκούρο Πορτοκαλί',
		FFD700: 'Χρυσαφί',
		'008000': 'Πράσινο',
		'0FF': 'Κυανό',
		'00F': 'Μπλε',
		EE82EE: 'Μενεξεδί',
		A9A9A9: 'Ποντικί',
		FFA07A: 'Ανοικτό Σομόν',
		FFA500: 'Πορτοκαλί',
		FFFF00: 'Κίτρινο',
		'00FF00': 'Μοσχολέμονο',
		AFEEEE: 'Pale Turquoise',
		ADD8E6: 'Γαλάζιο',
		DDA0DD: 'Δαμασκηνί',
		D3D3D3: 'Ανοικτό Γκρι',
		FFF0F5: 'Lavender Blush',
		FAEBD7: 'Antique White',
		FFFFE0: 'Ανοικτό Κίτρινο',
		F0FFF0: 'Honeydew',
		F0FFFF: 'Γαλανό',
		F0F8FF: 'Alice Blue',
		E6E6FA: 'Ελαφρός Ιώδες',
		FFF: 'Λευκό',
		'1ABC9C': 'Έντονο Κυανό',
		'2ECC71': 'Σμαραγδί',
		'3498DB': 'Φωτεινό Μπλε',
		'9B59B6': 'Αμέθυστος',
		'4E5F70': 'Γκριζωπό Μπλε',
		'F1C40F': 'Ζωντανό Κίτρινο',
		'16A085': 'Σκοτεινό Κυανό',
		'27AE60': 'Σκοτεινό Σμαραγδί',
		'2980B9': 'Έντονο Μπλε',
		'8E44AD': 'Σκοτεινό Βιολετί',
		'2C3E50': 'Αποκορρεσμένο Μπλε',
		'F39C12': 'Πορτοκαλί',
		'E67E22': 'Καροτί',
		'E74C3C': 'Απαλό Κόκκινο',
		'ECF0F1': 'Φωτεινό Ασημί',
		'95A5A6': 'Φωτεινό Γκριζωπό Κυανό',
		'DDD': 'Φωτεινό Γκρι',
		'D35400': 'Κολοκυθί',
		'C0392B': 'Έντονο Κόκκινο',
		'BDC3C7': 'Αργυρό',
		'7F8C8D': 'Γκριζωπό Κυανό',
		'999': 'Σκοτεινό Γκρι'
	},
	more: 'Περισσότερα Χρώματα…',
	panelTitle: 'Χρώματα',
	textColorTitle: 'Χρώμα Κειμένου'
} );
